<div align="center">
  <a href="https://github.com/canxin121">
    <img src="https://socialify.git.ci/canxin121/Spark-GPT/image?forks=1&issues=1&language=1&logo=https%3A%2F%2Fcanxin121.github.io%2Fdocs%2Flogo.png&name=1&owner=1&pattern=Charlie%20Brown&pulls=1&stargazers=1&theme=auto" width="700" height="350">
  </a>
  <h1>Spark-GPT</h1>
  <p><em>Spark-GPT</em></p>
</div>

<p align="center">
    <a href="https://pypi.python.org/pypi/nonebot-plugin-spark-gpt">
    <img src="https://img.shields.io/pypi/v/nonebot-plugin-spark-gpt" alt="pypi">
    </a>
    <img src="https://img.shields.io/pypi/pyversions/nonebot-plugin-spark-gpt" alt="python">
    <img src="https://img.shields.io/pypi/dm/nonebot-plugin-spark-gpt" alt="pypi">
    <br />
    <a href="https://onebot.dev/">
    <img src="https://img.shields.io/badge/OneBot-v11-black?style=social&logo=data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAEAAAABABAMAAABYR2ztAAAAIVBMVEUAAAAAAAADAwMHBwceHh4UFBQNDQ0ZGRkoKCgvLy8iIiLWSdWYAAAAAXRSTlMAQObYZgAAAQVJREFUSMftlM0RgjAQhV+0ATYK6i1Xb+iMd0qgBEqgBEuwBOxU2QDKsjvojQPvkJ/ZL5sXkgWrFirK4MibYUdE3OR2nEpuKz1/q8CdNxNQgthZCXYVLjyoDQftaKuniHHWRnPh2GCUetR2/9HsMAXyUT4/3UHwtQT2AggSCGKeSAsFnxBIOuAggdh3AKTL7pDuCyABcMb0aQP7aM4AnAbc/wHwA5D2wDHTTe56gIIOUA/4YYV2e1sg713PXdZJAuncdZMAGkAukU9OAn40O849+0ornPwT93rphWF0mgAbauUrEOthlX8Zu7P5A6kZyKCJy75hhw1Mgr9RAUvX7A3csGqZegEdniCx30c3agAAAABJRU5ErkJggg==" alt="onebot">
    <a href="https://github.com/canxin121/nonebot_poe_chat/releases/">
    <img src="https://img.shields.io/github/last-commit/canxin121/nonebot_poe_chat" alt="github">
    </a>
</p>
<div align="left">

---

[![残心小站-文档库](https://github.com/canxin121/nonebot_poe_chat/blob/main/source/spark/cx.png )](https://canxin121.github.io/docs/docs/Spark_GPT.html )

> 详细教程（必看，否则不会使用） 点击链接跳转👇 点击图片跳转☝️
  
> 详细教程（必看，否则不会使用） 点击链接跳转👇 点击图片跳转☝️

>
## [必看教程-残心小站-文档库](https://canxin121.github.io/docs/docs/Spark_GPT.html )

> 用户交流群:[610948446](http://qm.qq.com/cgi-bin/qm/qr?_wv=1027&k=KHGqjjbiz6fpRr-W2X9SugTXThKFiprJ&authKey=LhpClaGtc4%2Ff3EL7f4IIIt7F94vLHJj4HSS8c2YCE55nRBRBtftzla%2Bgj7pa0fWX&noverify=0&group_code=610948446
)
---

- 目前支持将Poe,NewBing,Dalle,ChatGPT (session token)接入qq

| Image 1 | Image 2 |
|:-------:|:-------:|
| ![1](https://github.com/canxin121/Spark-GPT/blob/main/source/spark/demo(1).png) | ![2](https://github.com/canxin121/Spark-GPT/blob/main/source/spark/demo(2).png) |
| ![3](https://github.com/canxin121/Spark-GPT/blob/main/source/spark/demo(3).png) | ![4](https://github.com/canxin121/Spark-GPT/blob/main/source/spark/demo(4).png) |
| ![5](https://github.com/canxin121/Spark-GPT/blob/main/source/spark/demo(5).png) |                                   |
